@@ -24,7 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
@@ -32,7 +32,6 @@
 #define __GTK_MENU_BAR_H__
 
 
-#include <gdk/gdk.h>
 #include <gtk/gtkmenushell.h>
 
 
@@ -46,12 +45,16 @@ G_BEGIN_DECLS
 #define GTK_IS_MENU_BAR_CLASS(klass)    (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_MENU_BAR))
 #define GTK_MENU_BAR_GET_CLASS(obj)     (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_MENU_BAR, GtkMenuBarClass))
 
-typedef struct _GtkMenuBar       GtkMenuBar;
-typedef struct _GtkMenuBarClass  GtkMenuBarClass;
+typedef struct _GtkMenuBar         GtkMenuBar;
+typedef struct _GtkMenuBarPrivate  GtkMenuBarPrivate;
+typedef struct _GtkMenuBarClass    GtkMenuBarClass;
 
 struct _GtkMenuBar
 {
   GtkMenuShell menu_shell;
+
+  /*< private >*/
+  GtkMenuBarPrivate *priv;
 };
 
 struct _GtkMenuBarClass
@@ -76,12 +79,6 @@ GtkPackDirection gtk_menu_bar_get_child_pack_direction (GtkMenuBar       *menuba
 void             gtk_menu_bar_set_child_pack_direction (GtkMenuBar       *menubar,
 							GtkPackDirection  child_pack_dir);
 
-#ifndef GTK_DISABLE_DEPRECATED
-#define gtk_menu_bar_append(menu,child)	    gtk_menu_shell_append  ((GtkMenuShell *)(menu),(child))
-#define gtk_menu_bar_prepend(menu,child)    gtk_menu_shell_prepend ((GtkMenuShell *)(menu),(child))
-#define gtk_menu_bar_insert(menu,child,pos) gtk_menu_shell_insert ((GtkMenuShell *)(menu),(child),(pos))
-#endif /* GTK_DISABLE_DEPRECATED */
-
 /* Private functions */
 void _gtk_menu_bar_cycle_focus (GtkMenuBar       *menubar,
 				GtkDirectionType  dir);
